==> arla_0.23.orig.tar.gz: arla-0.23/arlad/adir.h <==
/*
 * Copyright (c) 1995, 1996, 1997, 1998 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by the Kungliga Tekniska
 *      Hgskolan and its contributors.
 * 
 * 4. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/*
 * Interface to directory handling routines
 */

/* $Id: adir.h,v 1.10 1998/11/14 04:04:02 lha Exp $ */

#ifndef _ADIR_H_
#define _ADIR_H_

#include "fs.h"
#include "cred.h"
#include "fcache.h"

int adir_lookup (VenusFid dir, const char *name, VenusFid *file,
		 CredCacheEntry *ce);

int
adir_lookup_fcacheentry (FCacheEntry *centry,  const char *name,
			 VenusFid *file, CredCacheEntry *ce);

int
adir_changefid (VenusFid dir,
		const char *name,
		VenusFid *file,
		CredCacheEntry *ce);

int
adir_emptyp (VenusFid dir,
	     CredCacheEntry *ce);

int adir_readdir (VenusFid dir,
		  void (*)(VenusFid *, const char *name, void *), 
		  void *arg,
		  CredCacheEntry *ce);

int
adir_creat (FCacheEntry *dir,
	    const char *filename,
	    AFSFid fid);

int
adir_remove (FCacheEntry *dir,
	     const char *name);

int
adir_mkdir (FCacheEntry *dir,
	    AFSFid dot,
	    AFSFid dot_dot);

#endif /* _ADIR_H_ */

==> arla_0.35.6.orig.tar.gz: arla-0.35.6/arlad/adir.h <==
/*
 * Copyright (c) 1995 - 2000 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/*
 * Interface to directory handling routines
 */

/* $Id: adir.h,v 1.14.2.1 2001/06/04 22:16:35 ahltorp Exp $ */

#ifndef _ADIR_H_
#define _ADIR_H_

#include "fs.h"
#include "cred.h"
#include "fcache.h"
#include "fdir.h"

int
adir_lookup (FCacheEntry *centry, const char *name, VenusFid *file);

int
adir_changefid (VenusFid *dir,
		const char *name,
		VenusFid *file,
		CredCacheEntry **ce);

int
adir_emptyp (VenusFid *dir,
	     CredCacheEntry **ce);

int adir_readdir (VenusFid *dir,
		  void (*)(VenusFid *, const char *name, void *), 
		  void *arg,
		  CredCacheEntry **ce);

int
adir_creat (FCacheEntry *dir,
	    const char *filename,
	    AFSFid fid);

int
adir_remove (FCacheEntry *dir,
	     const char *name);

int
adir_mkdir (FCacheEntry *dir,
	    AFSFid dot,
	    AFSFid dot_dot);

#endif /* _ADIR_H_ */
